@@ -1,11 +1,11 @@
 use strict;
 use warnings;
-package Dist::Zilla::Plugin::Deprecated; # git description: v0.005-5-g9f3d7b9
+package Dist::Zilla::Plugin::Deprecated; # git description: v0.006-6-g19e5f22
+# vim: set ts=8 sts=4 sw=4 tw=115 et :
 # ABSTRACT: Add metadata to your distribution marking it as deprecated
 # KEYWORDS: plugin metadata module distribution deprecated
-# vim: set ts=8 sts=4 sw=4 tw=115 et :
 
-our $VERSION = '0.006';
+our $VERSION = '0.007';
 
 use Moose;
 with 'Dist::Zilla::Role::MetaProvider';
@@ -56,7 +56,7 @@ sub metadata
     # of merge we need as in new CPAN::Meta::Merge
     $self->log_fatal('CPAN::Meta::Merge 2.150002 required to deprecate an individual module!')
         if eval { Dist::Zilla->VERSION('5.022') }
-            and not eval 'require CPAN::Meta::Merge; CPAN::Meta::Merge->VERSION("2.150002"); 1';
+            and not eval { require CPAN::Meta::Merge; CPAN::Meta::Merge->VERSION('2.150002') };
 
     return { provides => { map { $_ => { x_deprecated => 1 } } $self->modules } };
 }
@@ -75,7 +75,7 @@ Dist::Zilla::Plugin::Deprecated - Add metadata to your distribution marking it a
 
 =head1 VERSION
 
-version 0.006
+version 0.007
 
 =head1 SYNOPSIS
 
@@ -103,6 +103,25 @@ field to the C<provides> section of metadata.  Note that L<CPAN::Meta::Spec>
 requires you to populate the rest of C<provides> metadata through some
 other means, such as L<Dist::Zilla::Plugin::MetaProvides::Package>.
 
+=head2 Recommendations
+
+=for stopwords metacpan.org
+
+=over 4
+
+=item *
+
+When you mark a module as deprecated, prepend '(DEPRECATED)' to its abstract (the one-line module description used
+in the C<NAME> pod section, which is used to populate module lists on sites such as metacpan.org).
+
+=item *
+
+Add a warning in the code (usually in the main body of the module, outside of any subroutine):
+
+    warnings::warnif('deprecated', 'My::Module is deprecated and should no longer be used');
+
+=back
+
 =head1 CONFIGURATION OPTIONS
 
 =head2 C<module>
